{% extends '_base.html' %}
{% load static %}

{% block head_title %}{{ geo1.name }} vs {{ geo2.name }} - {{ block.super }}{% endblock %}
{% block head_facebook_tags %}
    <meta property="og:title" content="{{ WAZIMAP.name }} comparison: {{ geo1.name }} vs {{ geo2.name }}" />
    <meta property="og:site_name" content="{{ WAZIMAP.name }}" />
    <meta property="og:url" content="{{ WAZIMAP.url }}{{ request.path }}" />
    <meta property="og:description" content="Compare demographics between {{ geo1.name }} vs {{ geo2.name }}." />
    <meta property="og:type" content="article" />
{% endblock %}

{% block body_class %}profile-head2head-view{% endblock %}

{% block content_container %}

<div class="head2head-wrapper">
    <iframe class="frame-left" scrolling="no" src="{% url 'geography_detail' geography_id=geo_id1 %}"></iframe>
    <iframe class="frame-right" scrolling="no" src="{% url 'geography_detail' geography_id=geo_id2 %}"></iframe>

    <div class="clear"></div>
</div>
{% endblock %}

{% block body_javascript_extra %}
<script src="{% static 'js/head2head.js' %}"></script>
{% endblock %}
